@@ -9,6 +9,7 @@ import (
 	"src.elv.sh/pkg/cli/lscolors"
 	"src.elv.sh/pkg/cli/term"
 	"src.elv.sh/pkg/cli/tk"
+	"src.elv.sh/pkg/must"
 	"src.elv.sh/pkg/testutil"
 	"src.elv.sh/pkg/ui"
 )
@@ -139,7 +140,7 @@ func TestWidthRatio(t *testing.T) {
 	)
 }
 
-func TestGetSelectedName(t *testing.T) {
+func TestNavigation_SelectedName(t *testing.T) {
 	f := Setup()
 	defer f.Stop()
 
@@ -151,6 +152,21 @@ func TestGetSelectedName(t *testing.T) {
 	}
 }
 
+func TestNavigation_SelectedName_EmptyDirectory(t *testing.T) {
+	f := Setup()
+	defer f.Stop()
+
+	cursor := &testCursor{
+		root: testutil.Dir{"d": testutil.Dir{}},
+		pwd:  []string{"d"}}
+	w := startNavigation(f.App, NavigationSpec{Cursor: cursor})
+
+	wantName := ""
+	if name := w.SelectedName(); name != wantName {
+		t.Errorf("Got name %q, want %q", name, wantName)
+	}
+}
+
 func TestNavigation_FakeFS(t *testing.T) {
 	cursor := getTestCursor()
 	testNavigation(t, cursor)
@@ -160,7 +176,7 @@ func TestNavigation_RealFS(t *testing.T) {
 	testutil.InTempDir(t)
 	testutil.ApplyDir(testDir)
 
-	testutil.MustChdir("d")
+	must.Chdir("d")
 	testNavigation(t, nil)
 }
 
@@ -271,7 +287,7 @@ func testNavigation(t *testing.T, c NavigationCursor) {
 	// only shows d2 after filtering.
 	w.MutateFiltering(func(bool) bool { return true })
 	f.TTY.Inject(term.K('2'))
-	f.TestTTY(t,
+	dFilter2Buf := f.MakeBuffer(
 		"\n",
 		" NAVIGATING  2", Styles,
 		"************  ", term.DotHere, "\n",
@@ -282,6 +298,11 @@ func testNavigation(t *testing.T, c NavigationCursor) {
 		" f                   other.png          ", Styles,
 		"                    !!!!!!!!!!!!!!!!!!!!",
 	)
+	f.TTY.TestBuffer(t, dFilter2Buf)
+
+	// Unbound key while filtering is ignored.
+	f.TTY.Inject(term.K('a', ui.Alt))
+	f.TTY.TestBuffer(t, dFilter2Buf)
 	w.MutateFiltering(func(bool) bool { return false })
 
 	// Now move into d2, and test that the filter has been cleared when
