@@ -3,8 +3,8 @@ package term
 import (
 	"strings"
 
-	"github.com/elves/elvish/pkg/ui"
-	"github.com/elves/elvish/pkg/wcwidth"
+	"src.elv.sh/pkg/ui"
+	"src.elv.sh/pkg/wcwidth"
 )
 
 // BufferBuilder supports building of Buffer.
@@ -16,7 +16,7 @@ type BufferBuilder struct {
 	// will otherwise
 	EagerWrap bool
 	// Lines the content of the buffer.
-	Lines [][]Cell
+	Lines Lines
 	// Dot is what the user perceives as the cursor.
 	Dot Pos
 }
@@ -125,7 +125,7 @@ var DotHere = struct{ x struct{} }{}
 
 // MarkLines is like calling WriteStyled with ui.MarkLines(args...), but accepts
 // an additional special parameter DotHere to mark the position of the dot.
-func (bb *BufferBuilder) MarkLines(args ...interface{}) *BufferBuilder {
+func (bb *BufferBuilder) MarkLines(args ...any) *BufferBuilder {
 	for i, arg := range args {
 		if arg == DotHere {
 			return bb.WriteStyled(ui.MarkLines(args[:i]...)).
