@@ -123,7 +123,7 @@ func TestColView_Handle(t *testing.T) {
 }
 
 func TestDistribute(t *testing.T) {
-	tt.Test(t, tt.Fn("distribute", distribute), tt.Table{
+	tt.Test(t, distribute,
 		// Nice integer distributions.
 		Args(10, []int{1, 1}).Rets([]int{5, 5}),
 		Args(10, []int{2, 3}).Rets([]int{4, 6}),
@@ -131,5 +131,5 @@ func TestDistribute(t *testing.T) {
 		// Approximate integer distributions.
 		Args(10, []int{1, 1, 1}).Rets([]int{3, 3, 4}),
 		Args(5, []int{1, 1, 1}).Rets([]int{1, 2, 2}),
-	})
+	)
 }
