@@ -21,14 +21,14 @@ func TestEmbeddingRangingImplementsRanger(t *testing.T) {
 }
 
 func TestPointRanging(t *testing.T) {
-	tt.Test(t, tt.Fn("PointRanging", PointRanging), tt.Table{
+	tt.Test(t, PointRanging,
 		Args(1).Rets(Ranging{1, 1}),
-	})
+	)
 }
 
 func TestMixedRanging(t *testing.T) {
-	tt.Test(t, tt.Fn("MixedRanging", MixedRanging), tt.Table{
+	tt.Test(t, MixedRanging,
 		Args(Ranging{1, 2}, Ranging{0, 4}).Rets(Ranging{1, 4}),
 		Args(Ranging{0, 4}, Ranging{1, 2}).Rets(Ranging{0, 2}),
-	})
+	)
 }
