@@ -2,6 +2,7 @@ package complete
 
 import (
 	"fmt"
+	"io/fs"
 	"os"
 	"path/filepath"
 	"strings"
@@ -22,7 +23,19 @@ var eachExternal = fsutil.EachExternal
 // GenerateFileNames returns filename candidates that are suitable for completing
 // the last argument. It can be used in Config.ArgGenerator.
 func GenerateFileNames(args []string) ([]RawItem, error) {
-	return generateFileNames(args[len(args)-1], false)
+	if len(args) == 0 {
+		return nil, nil
+	}
+	return generateFileNames(args[len(args)-1], nil)
+}
+
+// GenerateFileNames returns directory name candidates that are suitable for
+// completing the last argument. It can be used in Config.ArgGenerator.
+func GenerateDirNames(args []string) ([]RawItem, error) {
+	if len(args) == 0 {
+		return nil, nil
+	}
+	return generateFileNames(args[len(args)-1], fs.FileInfo.IsDir)
 }
 
 // GenerateForSudo generates candidates for sudo.
@@ -32,7 +45,7 @@ func GenerateForSudo(args []string, ev *eval.Evaler, cfg Config) ([]RawItem, err
 		return nil, errNoCompletion
 	case len(args) == 2:
 		// Complete external commands.
-		return generateExternalCommands(args[1], ev)
+		return generateExternalCommands(args[1])
 	default:
 		return cfg.ArgGenerator(args[1:])
 	}
@@ -63,15 +76,25 @@ func generateArgs(args []string, ev *eval.Evaler, p np.Path, cfg Config) ([]RawI
 			items = append(items, noQuoteItem(sigil+parse.QuoteVariableName(ns+varname)))
 		})
 		return items, nil
+	case "del":
+		// This partially duplicates eachVariableInNs with ns = "", but we don't
+		// offer builtin variables.
+		var items []RawItem
+		addItem := func(varname string) {
+			items = append(items, noQuoteItem(parse.QuoteVariableName(varname)))
+		}
+		ev.Global().IterateKeysString(addItem)
+		eachDefinedVariable(p[len(p)-1], p[0].Range().From, addItem)
+		return items, nil
 	}
 
 	return cfg.ArgGenerator(args)
 }
 
-func generateExternalCommands(seed string, ev *eval.Evaler) ([]RawItem, error) {
+func generateExternalCommands(seed string) ([]RawItem, error) {
 	if fsutil.DontSearch(seed) {
 		// Completing a local external command name.
-		return generateFileNames(seed, true)
+		return generateFileNames(seed, executableOrDir)
 	}
 	var items []RawItem
 	eachExternal(func(s string) { items = append(items, PlainItem(s)) })
@@ -81,7 +104,7 @@ func generateExternalCommands(seed string, ev *eval.Evaler) ([]RawItem, error) {
 func generateCommands(seed string, ev *eval.Evaler, p np.Path) ([]RawItem, error) {
 	if fsutil.DontSearch(seed) {
 		// Completing a local external command name.
-		return generateFileNames(seed, true)
+		return generateFileNames(seed, executableOrDir)
 	}
 
 	var cands []RawItem
@@ -120,7 +143,7 @@ func generateCommands(seed string, ev *eval.Evaler, p np.Path) ([]RawItem, error
 	return cands, nil
 }
 
-func generateFileNames(seed string, onlyExecutable bool) ([]RawItem, error) {
+func generateFileNames(seed string, statPred func(fs.FileInfo) bool) ([]RawItem, error) {
 	var items []RawItem
 
 	dir, fileprefix := filepath.Split(seed)
@@ -148,9 +171,8 @@ func generateFileNames(seed string, onlyExecutable bool) ([]RawItem, error) {
 		if dotfile(fileprefix) != dotfile(name) {
 			continue
 		}
-		// Only accept searchable directories and executable files if
-		// executableOnly is true.
-		if onlyExecutable && !fsutil.IsExecutable(stat) && !stat.IsDir() {
+		// Apply statPred if given.
+		if statPred != nil && !statPred(stat) {
 			continue
 		}
 
@@ -181,6 +203,10 @@ func generateFileNames(seed string, onlyExecutable bool) ([]RawItem, error) {
 	return items, nil
 }
 
+func executableOrDir(stat fs.FileInfo) bool {
+	return fsutil.IsExecutable(stat) || stat.IsDir()
+}
+
 func generateIndices(v any) []RawItem {
 	var items []RawItem
 	vals.IterateKeys(v, func(k any) bool {
