@@ -14,7 +14,7 @@ func (p PlainItem) String() string { return string(p) }
 func (p PlainItem) Cook(q parse.PrimaryType) modes.CompletionItem {
 	s := string(p)
 	quoted, _ := parse.QuoteAs(s, q)
-	return modes.CompletionItem{ToInsert: quoted, ToShow: s}
+	return modes.CompletionItem{ToInsert: quoted, ToShow: ui.T(s)}
 }
 
 // noQuoteItem is a RawItem implementation that does not quote when cooked. This
@@ -25,15 +25,14 @@ func (nq noQuoteItem) String() string { return string(nq) }
 
 func (nq noQuoteItem) Cook(parse.PrimaryType) modes.CompletionItem {
 	s := string(nq)
-	return modes.CompletionItem{ToInsert: s, ToShow: s}
+	return modes.CompletionItem{ToInsert: s, ToShow: ui.T(s)}
 }
 
 // ComplexItem is an implementation of RawItem that offers customization options.
 type ComplexItem struct {
-	Stem         string   // Used in the code and the menu.
-	CodeSuffix   string   // Appended to the code.
-	Display      string   // How the item is displayed. If empty, defaults to Stem.
-	DisplayStyle ui.Style // Use for displaying.
+	Stem       string  // Used in the code and the menu.
+	CodeSuffix string  // Appended to the code.
+	Display    ui.Text // How the item is displayed. If empty, defaults to ui.T(Stem).
 }
 
 func (c ComplexItem) String() string { return c.Stem }
@@ -41,12 +40,11 @@ func (c ComplexItem) String() string { return c.Stem }
 func (c ComplexItem) Cook(q parse.PrimaryType) modes.CompletionItem {
 	quoted, _ := parse.QuoteAs(c.Stem, q)
 	display := c.Display
-	if display == "" {
-		display = c.Stem
+	if display == nil {
+		display = ui.T(c.Stem)
 	}
 	return modes.CompletionItem{
-		ToInsert:  quoted + c.CodeSuffix,
-		ToShow:    display,
-		ShowStyle: c.DisplayStyle,
+		ToInsert: quoted + c.CodeSuffix,
+		ToShow:   display,
 	}
 }
