@@ -6,7 +6,6 @@ import (
 	"testing"
 	"time"
 
-	"src.elv.sh/pkg/diag"
 	"src.elv.sh/pkg/eval"
 	"src.elv.sh/pkg/parse"
 	"src.elv.sh/pkg/testutil"
@@ -84,30 +83,25 @@ func TestHighlighter_AutofixesAndCheckErrors(t *testing.T) {
 	ev := eval.NewEvaler()
 	ev.AddModule("mod1", &eval.Ns{})
 	hl := NewHighlighter(Config{
-		Check: func(t parse.Tree) (string, []diag.RangeError) {
+		Check: func(t parse.Tree) (string, []*eval.CompilationError) {
 			autofixes, err := ev.CheckTree(t, nil)
-			compErrors := eval.UnpackCompilationErrors(err)
-			rangeErrors := make([]diag.RangeError, len(compErrors))
-			for i, compErr := range compErrors {
-				rangeErrors[i] = compErr
-			}
-			return strings.Join(autofixes, "; "), rangeErrors
+			return strings.Join(autofixes, "; "), eval.UnpackCompilationErrors(err)
 		},
 		AutofixTip: func(s string) ui.Text { return ui.T("autofix: " + s) },
 	})
 
 	tt.Test(t, tt.Fn(hl.Get).Named("hl.Get"),
 		// Check error is highlighted and returned
-		Args("ls $a").Rets(
+		Args("ls $a ").Rets(
 			ui.MarkLines(
-				"ls $a", styles,
-				"vv ??"),
+				"ls $a ", styles,
+				"vv ?? "),
 			matchTexts("1:4")),
 		// Multiple check errors
-		Args("ls $a $b").Rets(
+		Args("ls $a $b ").Rets(
 			ui.MarkLines(
-				"ls $a $b", styles,
-				"vv ?? ??"),
+				"ls $a $b ", styles,
+				"vv ?? ?? "),
 			matchTexts("1:4", "1:7")),
 		// Check errors at the end are ignored
 		Args("set _").Rets(any, noTips),
@@ -116,9 +110,8 @@ func TestHighlighter_AutofixesAndCheckErrors(t *testing.T) {
 		Args("nop $mod1:").Rets(
 			ui.MarkLines(
 				"nop $mod1:", styles,
-				"vvv ??????"),
+				"vvv $$$$$$"),
 			matchTexts(
-				"1:5",               // error
 				"autofix: use mod1", // autofix
 			)),
 	)
