@@ -3,30 +3,31 @@ package edit
 import (
 	"sync"
 
-	"github.com/elves/elvish/pkg/cli/histutil"
-	"github.com/elves/elvish/pkg/store"
+	"src.elv.sh/pkg/cli/histutil"
+	"src.elv.sh/pkg/store/storedefs"
 )
 
 // A wrapper of histutil.Store that is concurrency-safe and supports an
 // additional FastForward method.
 type histStore struct {
 	m  sync.Mutex
-	db store.Store
+	db storedefs.Store
 	hs histutil.Store
 }
 
-func newHistStore(db store.Store) (*histStore, error) {
+func newHistStore(db storedefs.Store) (*histStore, error) {
 	hs, err := histutil.NewHybridStore(db)
 	return &histStore{db: db, hs: hs}, err
 }
 
-func (s *histStore) AddCmd(cmd store.Cmd) (int, error) {
+func (s *histStore) AddCmd(cmd storedefs.Cmd) (int, error) {
 	s.m.Lock()
 	defer s.m.Unlock()
 	return s.hs.AddCmd(cmd)
 }
 
-func (s *histStore) AllCmds() ([]store.Cmd, error) {
+// AllCmds returns a slice of all interactive commands in oldest to newest order.
+func (s *histStore) AllCmds() ([]storedefs.Cmd, error) {
 	s.m.Lock()
 	defer s.m.Unlock()
 	return s.hs.AllCmds()
@@ -63,7 +64,7 @@ func (c cursor) Next() {
 	c.c.Next()
 }
 
-func (c cursor) Get() (store.Cmd, error) {
+func (c cursor) Get() (storedefs.Cmd, error) {
 	c.m.Lock()
 	defer c.m.Unlock()
 	return c.c.Get()
