@@ -28,15 +28,23 @@ func TestDot(t *testing.T) {
 	f := setup(t)
 
 	f.SetCodeBuffer(tk.CodeBuffer{Content: "code", Dot: 4})
-	evals(f.Evaler, `edit:-dot = 0`)
+	evals(f.Evaler, `set edit:-dot = 0`)
 
 	testCodeBuffer(t, f.Editor, tk.CodeBuffer{Content: "code", Dot: 0})
 }
 
+func TestDotOutOfBoundary(t *testing.T) {
+	f := setup(t)
+
+	f.SetCodeBuffer(tk.CodeBuffer{Content: "", Dot: 0})
+	evals(f.Evaler, "var err = ?(set edit:-dot = 10)[reason]")
+	testGlobal(t, f.Evaler, "err", errDotOutOfBoundary)
+}
+
 func TestCurrentCommand(t *testing.T) {
 	f := setup(t)
 
-	evals(f.Evaler, `edit:current-command = code`)
+	evals(f.Evaler, `set edit:current-command = code`)
 
 	testCodeBuffer(t, f.Editor, tk.CodeBuffer{Content: "code", Dot: 4})
 }
