@@ -17,7 +17,7 @@ func init() {
 }
 
 func src(fm *Frame) parse.Source {
-	return fm.srcMeta
+	return fm.src
 }
 
 func _gc() {
