@@ -5,6 +5,7 @@ import (
 	"encoding/json"
 	"fmt"
 	"io"
+	"math/big"
 	"strconv"
 	"strings"
 
@@ -24,8 +25,9 @@ func init() {
 		"repeat": repeat,
 
 		// Bytes input
-		"read-upto": readUpto,
-		"read-line": readLine,
+		"read-bytes": readBytes,
+		"read-upto":  readUpto,
+		"read-line":  readLine,
 
 		// Bytes output
 		"print":  print,
@@ -79,6 +81,22 @@ func repeat(fm *Frame, n int, v any) error {
 	return nil
 }
 
+func readBytes(fm *Frame, max int) (string, error) {
+	in := fm.InputFile()
+	buf := make([]byte, max)
+	read := 0
+	for read < max {
+		n, err := in.Read(buf[read:])
+		read += n
+		if err == io.EOF {
+			break
+		} else if err != nil {
+			return "", err
+		}
+	}
+	return string(buf[:read]), nil
+}
+
 func readUpto(fm *Frame, terminator string) (string, error) {
 	if err := checkTerminator(terminator); err != nil {
 		return "", err
@@ -336,6 +354,8 @@ func fromJSON(fm *Frame) error {
 	out := fm.ValueOutput()
 
 	dec := json.NewDecoder(in)
+	// See comments below about using json.Number.
+	dec.UseNumber()
 	for {
 		var v any
 		err := dec.Decode(&v)
@@ -361,6 +381,17 @@ func fromJSONInterface(v any) (any, error) {
 	switch v := v.(type) {
 	case nil, bool, string:
 		return v, nil
+	case json.Number:
+		// The JSON syntax doesn't restrict the precision of numbers. Since
+		// we called json.Decoder.UseNumber, it preserves the full number
+		// literal, and we can try parsing it as a big int.
+		if z, ok := new(big.Int).SetString(v.String(), 0); ok {
+			// Also normalize to int if the value fits.
+			return vals.NormalizeBigInt(z), nil
+		}
+		// Parse as float64 instead. This can error if the number is not an
+		// integer and exceeds the range of float64.
+		return strconv.ParseFloat(v.String(), 64)
 	case float64:
 		return v, nil
 	case []any:
