@@ -1,7 +1,6 @@
 package eval
 
 import (
-	"embed"
 	"strconv"
 	"syscall"
 
@@ -25,8 +24,3 @@ var builtinNs = BuildNsNamed("").AddVars(map[string]vars.Var{
 func addBuiltinFns(fns map[string]any) {
 	builtinNs.AddGoFns(fns)
 }
-
-// BuiltinDElvFiles embeds all the .d.elv files for the builtin module.
-//
-//go:embed *.d.elv
-var BuiltinDElvFiles embed.FS
