@@ -263,7 +263,11 @@ func (cp *compiler) primaryOp(n *parse.Primary) valuesOp {
 		ref := resolveVarRef(cp, qname, n)
 		if ref == nil {
 			cp.autofixUnresolvedVar(qname)
-			cp.errorpf(n, "variable $%s not found", parse.Quote(qname))
+			// The variable name might be a prefix of a valid variable name.
+			// Ideally, we'd want to match the variable name to all possible
+			// names to check if that's actually the case, but it's a bit
+			// expensive and let's call this good enough for now.
+			cp.errorpfPartial(n, "variable $%s not found", parse.Quote(qname))
 		}
 		return &variableOp{n.Range(), sigil != "", qname, ref}
 	case parse.Wildcard:
@@ -366,7 +370,7 @@ func (op outputCaptureOp) exec(fm *Frame) ([]any, Exception) {
 	if err != nil {
 		return nil, fm.errorp(op, err)
 	}
-	exc := op.subop.exec(fm.forkWithOutput("[output capture]", outPort))
+	exc := op.subop.exec(fm.forkWithOutput(outPort))
 	return collect(), exc
 }
 
@@ -381,6 +385,7 @@ func (cp *compiler) lambda(n *parse.Primary) valuesOp {
 	if len(n.Elements) > 0 {
 		// Argument list.
 		argNames = make([]string, len(n.Elements))
+		seenName := make(map[string]bool)
 		for i, arg := range n.Elements {
 			ref := stringLiteralOrError(cp, arg, "argument name")
 			sigil, qname := SplitSigil(ref)
@@ -389,7 +394,7 @@ func (cp *compiler) lambda(n *parse.Primary) valuesOp {
 				cp.errorpf(arg, "argument name must be unqualified")
 			}
 			if name == "" {
-				cp.errorpf(arg, "argument name must not be empty")
+				cp.errorpfPartial(arg, "argument name must not be empty")
 			}
 			if sigil == "@" {
 				if restArg != -1 {
@@ -397,6 +402,13 @@ func (cp *compiler) lambda(n *parse.Primary) valuesOp {
 				}
 				restArg = i
 			}
+			if name != "_" {
+				if seenName[name] {
+					cp.errorpfPartial(arg, "duplicate argument name '%s'", name)
+				} else {
+					seenName[name] = true
+				}
+			}
 			argNames[i] = name
 		}
 	}
@@ -410,11 +422,11 @@ func (cp *compiler) lambda(n *parse.Primary) valuesOp {
 				cp.errorpf(opt.Key, "option name must be unqualified")
 			}
 			if name == "" {
-				cp.errorpf(opt.Key, "option name must not be empty")
+				cp.errorpfPartial(opt.Key, "option name must not be empty")
 			}
 			optNames[i] = name
 			if opt.Value == nil {
-				cp.errorpf(opt.Key, "option must have default value")
+				cp.errorpfPartial(opt.Key, "option must have default value")
 			} else {
 				optDefaultOps[i] = cp.compoundOp(opt.Value)
 			}
@@ -433,7 +445,7 @@ func (cp *compiler) lambda(n *parse.Primary) valuesOp {
 	newLocal := local.infos[scopeSizeInit:]
 	cp.popScope()
 
-	return &lambdaOp{n.Range(), argNames, restArg, optNames, optDefaultOps, newLocal, capture, chunkOp, cp.srcMeta}
+	return &lambdaOp{n.Range(), argNames, restArg, optNames, optDefaultOps, newLocal, capture, chunkOp, cp.src}
 }
 
 type lambdaOp struct {
