@@ -1,5 +1,4 @@
 //go:build gccgo
-// +build gccgo
 
 package eval
 
@@ -13,6 +12,6 @@ func pluginOpen(name string) (pluginStub, error) {
 	return pluginStub{}, errPluginNotImplemented
 }
 
-func (pluginStub) Lookup(symName string) (interface{}, error) {
+func (pluginStub) Lookup(symName string) (any, error) {
 	return nil, errPluginNotImplemented
 }
