@@ -17,10 +17,15 @@ type List = vector.Vector
 var EmptyList = vector.Empty
 
 // MakeList creates a new List from values.
-func MakeList(vs ...interface{}) vector.Vector {
+func MakeList(vs ...any) vector.Vector {
+	return MakeListSlice(vs)
+}
+
+// MakeListSlice creates a new List from a slice.
+func MakeListSlice[T any](vs []T) vector.Vector {
 	vec := vector.Empty
 	for _, v := range vs {
-		vec = vec.Cons(v)
+		vec = vec.Conj(v)
 	}
 	return vec
 }
@@ -33,7 +38,7 @@ var EmptyMap = hashmap.New(Equal, Hash)
 
 // MakeMap creates a map from arguments that are alternately keys and values. It
 // panics if the number of arguments is odd.
-func MakeMap(a ...interface{}) hashmap.Map {
+func MakeMap(a ...any) hashmap.Map {
 	if len(a)%2 == 1 {
 		panic("odd number of arguments to MakeMap")
 	}
