@@ -11,12 +11,12 @@ type Concatter interface {
 	// Concat concatenates the receiver with another value, the receiver being
 	// the left operand. If concatenation is not supported for the given value,
 	// the method can return the special error type ErrCatNotImplemented.
-	Concat(v interface{}) (interface{}, error)
+	Concat(v any) (any, error)
 }
 
 // RConcatter wraps the RConcat method. See Concat for how it is used.
 type RConcatter interface {
-	RConcat(v interface{}) (interface{}, error)
+	RConcat(v any) (any, error)
 }
 
 // ErrConcatNotImplemented is a special error value used to signal that
@@ -37,7 +37,7 @@ func (err cannotConcat) Error() string {
 // lhs.Concat(rhs). If lhs doesn't implement the interface or returned
 // ErrConcatNotImplemented, it then calls rhs.RConcat(lhs). If all attempts
 // fail, it returns nil and an error.
-func Concat(lhs, rhs interface{}) (interface{}, error) {
+func Concat(lhs, rhs any) (any, error) {
 	if v, ok := tryConcatBuiltins(lhs, rhs); ok {
 		return v, nil
 	}
@@ -59,7 +59,7 @@ func Concat(lhs, rhs interface{}) (interface{}, error) {
 	return nil, cannotConcat{Kind(lhs), Kind(rhs)}
 }
 
-func tryConcatBuiltins(lhs, rhs interface{}) (interface{}, bool) {
+func tryConcatBuiltins(lhs, rhs any) (any, bool) {
 	switch lhs := lhs.(type) {
 	case string, int, *big.Int, *big.Rat, float64:
 		switch rhs := rhs.(type) {
