@@ -8,6 +8,7 @@ import (
 	"unsafe"
 
 	"src.elv.sh/pkg/persistent/hash"
+	"src.elv.sh/pkg/persistent/hashmap"
 	"src.elv.sh/pkg/tt"
 )
 
@@ -23,7 +24,7 @@ func TestHash(t *testing.T) {
 	z.Add(z, big.NewInt(9))
 	// z = 5 << wordSize + 9
 
-	tt.Test(t, tt.Fn("Hash", Hash), tt.Table{
+	tt.Test(t, Hash,
 		Args(false).Rets(uint32(0)),
 		Args(true).Rets(uint32(1)),
 		Args(1).Rets(uint32(1)),
@@ -37,5 +38,20 @@ func TestHash(t *testing.T) {
 			Rets(hash.DJB(Hash("foo"), Hash("bar"))),
 		Args(hasher{}).Rets(uint32(42)),
 		Args(nonHasher{}).Rets(uint32(0)),
-	})
+	)
+}
+
+func TestHash_EqualMapsWithDifferentInternal(t *testing.T) {
+	// The internal representation of maps with the same value is not always the
+	// same: when some keys of the map have the same hash, their values are
+	// stored in the insertion order.
+	//
+	// To reliably test this case, we construct maps with a custom hashing
+	// function.
+	m0 := hashmap.New(Equal, func(v any) uint32 { return 0 })
+	m1 := m0.Assoc("k1", "v1").Assoc("k2", "v2")
+	m2 := m0.Assoc("k2", "v2").Assoc("k1", "v1")
+	if h1, h2 := Hash(m1), Hash(m2); h1 != h2 {
+		t.Errorf("%v != %v", h1, h2)
+	}
 }
