@@ -17,12 +17,12 @@ func (k keysIterator) IterateKeys(f func(any) bool) {
 type nonKeysIterator struct{}
 
 func TestIterateKeys(t *testing.T) {
-	tt.Test(t, tt.Fn("collectKeys", collectKeys), tt.Table{
+	tt.Test(t, tt.Fn(collectKeys).Named("collectKeys"),
 		Args(MakeMap("k1", "v1", "k2", "v2")).Rets(vs("k1", "k2"), nil),
 		Args(keysIterator{vs("lorem", "ipsum")}).Rets(vs("lorem", "ipsum")),
 		Args(nonKeysIterator{}).Rets(
 			tt.Any, cannotIterateKeysOf{"!!vals.nonKeysIterator"}),
-	})
+	)
 }
 
 func TestIterateKeys_Map_Break(t *testing.T) {
