@@ -25,25 +25,25 @@ const (
 )
 
 func TestParseNum(t *testing.T) {
-	tt.Test(t, tt.Fn("ParseNum", ParseNum), tt.Table{
+	tt.Test(t, ParseNum,
 		Args("1").Rets(1),
 
 		Args(z).Rets(bigInt(z)),
 
 		Args("1/2").Rets(big.NewRat(1, 2)),
 		Args("2/1").Rets(2),
-		Args(z + "/1").Rets(bigInt(z)),
+		Args(z+"/1").Rets(bigInt(z)),
 
 		Args("1.0").Rets(1.0),
 		Args("1e-5").Rets(1e-5),
 
 		Args("x").Rets(nil),
 		Args("x/y").Rets(nil),
-	})
+	)
 }
 
 func TestUnifyNums(t *testing.T) {
-	tt.Test(t, tt.Fn("UnifyNums", UnifyNums), tt.Table{
+	tt.Test(t, UnifyNums,
 		Args([]Num{1, 2, 3, 4}, Int).
 			Rets([]int{1, 2, 3, 4}),
 
@@ -70,26 +70,52 @@ func TestUnifyNums(t *testing.T) {
 		Args([]Num{1, 2, 3, 4}, BigInt).
 			Rets([]*big.Int{
 				big.NewInt(1), big.NewInt(2), big.NewInt(3), big.NewInt(4)}),
-	})
+	)
 }
 
 func TestUnifyNums2(t *testing.T) {
-	tt.Test(t, tt.Fn("UnifyNums2", UnifyNums2), tt.Table{
+	tt.Test(t, UnifyNums2,
 		Args(1, 2, Int).Rets(1, 2),
 		Args(1, bigInt(z), Int).Rets(big.NewInt(1), bigInt(z)),
 		Args(1, big.NewRat(1, 2), Int).Rets(big.NewRat(1, 1), big.NewRat(1, 2)),
 		Args(1, 2.0, Int).Rets(1.0, 2.0),
 		Args(1, 2, BigInt).Rets(big.NewInt(1), big.NewInt(2)),
-	})
+	)
 }
 
 func TestInvalidNumType(t *testing.T) {
-	tt.Test(t, tt.Fn("Recover", testutil.Recover), tt.Table{
+	tt.Test(t, testutil.Recover,
 		Args(func() { UnifyNums([]Num{int32(0)}, 0) }).Rets("invalid num type int32"),
 		Args(func() { PromoteToBigInt(int32(0)) }).Rets("invalid num type int32"),
 		Args(func() { PromoteToBigRat(int32(0)) }).Rets("invalid num type int32"),
 		Args(func() { ConvertToFloat64(int32(0)) }).Rets("invalid num type int32"),
-	})
+	)
+}
+
+func TestInt64ToNum(t *testing.T) {
+	n := Int64ToNum(1)
+	if _, isInt := n.(int); !isInt {
+		t.Errorf("got %T, want int", n)
+	}
+
+	if math.MaxInt != math.MaxInt64 {
+		n = Int64ToNum(math.MaxInt64)
+		if _, isBigInt := n.(*big.Int); !isBigInt {
+			t.Errorf("got %T, want *big.Int", n)
+		}
+	}
+}
+
+func TestUint64ToNum(t *testing.T) {
+	n := Uint64ToNum(1)
+	if _, isInt := n.(int); !isInt {
+		t.Errorf("got %T, want int", n)
+	}
+
+	n = Uint64ToNum(math.MaxUint64)
+	if _, isBigInt := n.(*big.Int); !isBigInt {
+		t.Errorf("got %T, want *big.Int", n)
+	}
 }
 
 func bigInt(s string) *big.Int {
