@@ -52,10 +52,8 @@ type scopeSearcher interface {
 // Resolves a qname into a varRef.
 func resolveVarRef(s scopeSearcher, qname string, r diag.Ranger) *varRef {
 	if strings.HasPrefix(qname, ":") {
-		qname = qname[1:]
-		if cp, ok := s.(*compiler); ok {
-			cp.deprecate(r, "the empty namespace is deprecated; use the variable directly instead", 17)
-		}
+		// $:foo is reserved for fully-qualified names in future
+		return nil
 	}
 	if ref := resolveVarRefLocal(s, qname); ref != nil {
 		return ref
@@ -90,16 +88,6 @@ func resolveVarRefBuiltin(s scopeSearcher, qname string, r diag.Ranger) *varRef
 	if rest != "" {
 		// Try special namespace first.
 		switch first {
-		case "local:":
-			if cp, ok := s.(*compiler); ok {
-				cp.deprecate(r, "the local: special namespace is deprecated; use the variable directly instead", 17)
-			}
-			return resolveVarRefLocal(s, rest)
-		case "up:":
-			if cp, ok := s.(*compiler); ok {
-				cp.deprecate(r, "the up: special namespace is deprecated; use the variable directly if it is not shadowed", 17)
-			}
-			return resolveVarRefCapture(s, rest)
 		case "e:":
 			if strings.HasSuffix(rest, FnSuffix) {
 				return &varRef{scope: externalScope, subNames: []string{rest[:len(rest)-1]}}
