@@ -3,13 +3,16 @@ package lsp
 import (
 	"context"
 	"encoding/json"
+	"fmt"
 
-	lsp "github.com/sourcegraph/go-lsp"
 	"github.com/sourcegraph/jsonrpc2"
+	lsp "pkg.nimblebun.works/go-lsp"
 	"src.elv.sh/pkg/diag"
 	"src.elv.sh/pkg/edit/complete"
 	"src.elv.sh/pkg/eval"
+	"src.elv.sh/pkg/mods/doc"
 	"src.elv.sh/pkg/parse"
+	"src.elv.sh/pkg/parse/np"
 )
 
 var (
@@ -20,12 +23,18 @@ var (
 )
 
 type server struct {
-	evaler  *eval.Evaler
-	content map[lsp.DocumentURI]string
+	evaler    *eval.Evaler
+	documents map[lsp.DocumentURI]document
+}
+
+type document struct {
+	code      string
+	parseTree parse.Tree
+	parseErr  error
 }
 
 func newServer() *server {
-	return &server{eval.NewEvaler(), make(map[lsp.DocumentURI]string)}
+	return &server{eval.NewEvaler(), make(map[lsp.DocumentURI]document)}
 }
 
 func handler(s *server) jsonrpc2.Handler {
@@ -33,7 +42,7 @@ func handler(s *server) jsonrpc2.Handler {
 		"initialize":              s.initialize,
 		"textDocument/didOpen":    convertMethod(s.didOpen),
 		"textDocument/didChange":  convertMethod(s.didChange),
-		"textDocument/hover":      s.hover,
+		"textDocument/hover":      convertMethod(s.hover),
 		"textDocument/completion": convertMethod(s.completion),
 
 		"textDocument/didClose": noop,
@@ -71,6 +80,8 @@ func routingHandler(methods map[string]method) jsonrpc2.Handler {
 	})
 }
 
+// Can be used within handler implementations to recover the connection stored
+// in the Context.
 func conn(ctx context.Context) *jsonrpc2.Conn { return ctx.Value(connKey{}).(*jsonrpc2.Conn) }
 
 // Handler implementations. These are all called synchronously.
@@ -78,21 +89,19 @@ func conn(ctx context.Context) *jsonrpc2.Conn { return ctx.Value(connKey{}).(*js
 func (s *server) initialize(_ context.Context, _ json.RawMessage) (any, error) {
 	return &lsp.InitializeResult{
 		Capabilities: lsp.ServerCapabilities{
-			TextDocumentSync: &lsp.TextDocumentSyncOptionsOrKind{
-				Options: &lsp.TextDocumentSyncOptions{
-					OpenClose: true,
-					Change:    lsp.TDSKFull,
-				},
+			TextDocumentSync: &lsp.TextDocumentSyncOptions{
+				OpenClose: true,
+				Change:    lsp.TDSyncKindFull,
 			},
 			CompletionProvider: &lsp.CompletionOptions{},
+			HoverProvider:      &lsp.HoverOptions{},
 		},
 	}, nil
 }
 
 func (s *server) didOpen(ctx context.Context, params lsp.DidOpenTextDocumentParams) (any, error) {
 	uri, content := params.TextDocument.URI, params.TextDocument.Text
-	s.content[uri] = content
-	go publishDiagnostics(ctx, uri, content)
+	s.updateDocument(conn(ctx), uri, content)
 	return nil, nil
 }
 
@@ -100,21 +109,50 @@ func (s *server) didChange(ctx context.Context, params lsp.DidChangeTextDocument
 	// ContentChanges includes full text since the server is only advertised to
 	// support that; see the initialize method.
 	uri, content := params.TextDocument.URI, params.ContentChanges[0].Text
-	s.content[uri] = content
-	go publishDiagnostics(ctx, uri, content)
+	s.updateDocument(conn(ctx), uri, content)
 	return nil, nil
 }
 
-func (s *server) hover(_ context.Context, rawParams json.RawMessage) (any, error) {
-	return lsp.Hover{}, nil
+func (s *server) hover(_ context.Context, params lsp.TextDocumentPositionParams) (any, error) {
+	document, ok := s.documents[params.TextDocument.URI]
+	if !ok {
+		return nil, unknownDocument(params.TextDocument.URI)
+	}
+	pos := lspPositionToIdx(document.code, params.Position)
+
+	p := np.Find(document.parseTree.Root, pos)
+	// Try variable doc
+	var primary *parse.Primary
+	if p.Match(np.Store(&primary)) && primary.Type == parse.Variable {
+		// TODO: Take shadowing into consideration.
+		markdown, err := doc.Source("$" + primary.Value)
+		if err == nil {
+			return lsp.Hover{Contents: lsp.MarkupContent{Kind: lsp.MKMarkdown, Value: markdown}}, nil
+		}
+	}
+	// Try command doc
+	var expr np.SimpleExprData
+	var form *parse.Form
+	if p.Match(np.SimpleExpr(&expr, nil), np.Store(&form)) && form.Head == expr.Compound {
+		// TODO: Take shadowing into consideration.
+		markdown, err := doc.Source(expr.Value)
+		if err == nil {
+			return lsp.Hover{Contents: lsp.MarkupContent{Kind: lsp.MKMarkdown, Value: markdown}}, nil
+		}
+	}
+	return nil, nil
 }
 
 func (s *server) completion(_ context.Context, params lsp.CompletionParams) (any, error) {
-	content := s.content[params.TextDocument.URI]
+	document, ok := s.documents[params.TextDocument.URI]
+	if !ok {
+		return nil, unknownDocument(params.TextDocument.URI)
+	}
+	code := document.code
 	result, err := complete.Complete(
 		complete.CodeBuffer{
-			Content: content,
-			Dot:     lspPositionToIdx(content, params.Position)},
+			Content: code,
+			Dot:     lspPositionToIdx(code, params.Position)},
 		s.evaler,
 		complete.Config{},
 	)
@@ -124,7 +162,7 @@ func (s *server) completion(_ context.Context, params lsp.CompletionParams) (any
 	}
 
 	lspItems := make([]lsp.CompletionItem, len(result.Items))
-	lspRange := lspRangeFromRange(content, result.Replace)
+	lspRange := lspRangeFromRange(code, result.Replace)
 	var kind lsp.CompletionItemKind
 	switch result.Name {
 	case "command":
@@ -147,28 +185,31 @@ func (s *server) completion(_ context.Context, params lsp.CompletionParams) (any
 	return lspItems, nil
 }
 
-func publishDiagnostics(ctx context.Context, uri lsp.DocumentURI, content string) {
-	conn(ctx).Notify(ctx, "textDocument/publishDiagnostics",
-		lsp.PublishDiagnosticsParams{URI: uri, Diagnostics: diagnostics(uri, content)})
+func (s *server) updateDocument(conn *jsonrpc2.Conn, uri lsp.DocumentURI, code string) {
+	tree, err := parse.Parse(parse.Source{Name: string(uri), Code: code}, parse.Config{})
+	s.documents[uri] = document{code, tree, err}
+	go func() {
+		// Convert the parse error to lsp.Diagnostic objects and publish them.
+		entries := parse.UnpackErrors(err)
+		diags := make([]lsp.Diagnostic, len(entries))
+		for i, err := range entries {
+			diags[i] = lsp.Diagnostic{
+				Range:    lspRangeFromRange(code, err),
+				Severity: lsp.DSError,
+				Source:   "parse",
+				Message:  err.Message,
+			}
+		}
+		conn.Notify(context.Background(), "textDocument/publishDiagnostics",
+			lsp.PublishDiagnosticsParams{URI: uri, Diagnostics: diags})
+	}()
 }
 
-func diagnostics(uri lsp.DocumentURI, content string) []lsp.Diagnostic {
-	_, err := parse.Parse(parse.Source{Name: string(uri), Code: content}, parse.Config{})
-	if err == nil {
-		return []lsp.Diagnostic{}
+func unknownDocument(uri lsp.DocumentURI) error {
+	return &jsonrpc2.Error{
+		Code:    jsonrpc2.CodeInvalidParams,
+		Message: fmt.Sprintf("unknown document: %v", uri),
 	}
-
-	entries := parse.UnpackErrors(err)
-	diags := make([]lsp.Diagnostic, len(entries))
-	for i, err := range entries {
-		diags[i] = lsp.Diagnostic{
-			Range:    lspRangeFromRange(content, err),
-			Severity: lsp.Error,
-			Source:   "parse",
-			Message:  err.Message,
-		}
-	}
-	return diags
 }
 
 func lspRangeFromRange(s string, r diag.Ranger) lsp.Range {
