@@ -100,16 +100,15 @@
 //
 //   - Lists are always considered [loose].
 //
+// The package also supports the following extensions:
+//
+//   - ATX headers may be followed by [Pandoc header attributes] {...}.
+//
 // These omitted features are never used in Elvish's Markdown sources.
 //
-// All implemented features pass their relevant CommonMark spec tests. See
-// [testutils_test.go] for a complete list of which spec tests are skipped.
-//
-// Note: the spec tests were taken from the [CommonMark spec Git repo] on
-// 2022-09-26. This version is almost identical to the latest released version,
-// [CommonMark 0.30] (released 2021-06-09), with two minor changes in the syntax
-// of [HTML blocks] and [inline HTML comments]. Once CommonMark 0.31 is
-// released, the spec tests will be updated to follow that instead.
+// All implemented features pass their relevant CommonMark spec tests, currently
+// targeting [CommonMark 0.31.2]. See [testutils_test.go] for a complete list of
+// which spec tests are skipped.
 //
 // # Is this package useful outside Elvish?
 //
@@ -142,23 +141,21 @@
 //     correctness, the corner cases will be interesting, regardless of which
 //     language you are using to implement the formatter.
 //
+// [Pandoc header attributes]: https://pandoc.org/MANUAL.html#extension-header_attributes
 // [all the corner cases found by the fuzzer]: https://github.com/elves/elvish/tree/master/pkg/md/testdata/fuzz/FuzzFmtPreservesHTMLRender
 // [fuzzing support]: https://go.dev/security/fuzz/
-// [CommonMark 0.30]: https://spec.commonmark.org/0.30/
-// [HTML blocks]: https://github.com/commonmark/commonmark-spec/commit/053924aa51ea56db1899403068540f90b761125a
-// [inline HTML comments]: https://github.com/commonmark/commonmark-spec/commit/d5ddfae696c53f09fd5b6182238de716dddeb40a
-// [loose]: https://spec.commonmark.org/0.30/#loose
-// [Setext headings]: https://spec.commonmark.org/0.30/#setext-headings
-// [ATX headings]: https://spec.commonmark.org/0.30/#atx-headings
+// [loose]: https://spec.commonmark.org/0.31.2/#loose
+// [Setext headings]: https://spec.commonmark.org/0.31.2/#setext-headings
+// [ATX headings]: https://spec.commonmark.org/0.31.2/#atx-headings
 // [testutils_test.go]: https://github.com/elves/elvish/blob/master/pkg/md/testutils_test.go
 // [elvdoc]: https://github.com/elves/elvish/blob/master/CONTRIBUTING.md#reference-docs
 // [Pandoc]: https://pandoc.org
 // [Prettier]: https://prettier.io
 // [CommonMark]: https://spec.commonmark.org
 // [contributing instructions]: https://github.com/elves/elvish/blob/master/CONTRIBUTING.md
-// [inline links]: https://spec.commonmark.org/0.30/#inline-link
-// [Reference links]: https://spec.commonmark.org/0.30/#reference-link
-// [CommonMark spec Git repo]: https://github.com/commonmark/commonmark-spec
+// [inline links]: https://spec.commonmark.org/0.31.2/#inline-link
+// [Reference links]: https://spec.commonmark.org/0.31.2/#reference-link
+// [CommonMark 0.31.2]: https://spec.commonmark.org/0.31.2/
 package md
 
 //go:generate stringer -type=OpType,InlineOpType -output=zstring.go
@@ -180,7 +177,7 @@ import (
 // better CommonMark compliance.
 var UnescapeHTML = unescapeHTML
 
-// https://spec.commonmark.org/0.30/#entity-and-numeric-character-references
+// https://spec.commonmark.org/0.31.2/#entity-and-numeric-character-references
 const charRefPattern = `&(?:[a-zA-Z0-9]+|#[0-9]{1,7}|#[xX][0-9a-fA-F]{1,6});`
 
 var charRefRegexp = regexp.MustCompile(charRefPattern)
@@ -221,10 +218,16 @@ type Codec interface {
 // Op represents an operation for the Codec.
 type Op struct {
 	Type OpType
+	// 1-based line number. If the Op spans multiple lines, this identifies the
+	// first line. For the *End types, this identifies the first line that
+	// causes the block to be terminated, which can be the first line of another
+	// block.
+	LineNo int
 	// For OpOrderedListStart (the start number) or OpHeading (as the heading
 	// level)
 	Number int
-	// For OpHeading and OpCodeBlock
+	// For OpHeading (attributes inside { }) and OpCodeBlock (text after opening
+	// fence)
 	Info string
 	// For OpCodeBlock and OpHTMLBlock
 	Lines []string
@@ -262,7 +265,7 @@ func Render(text string, codec Codec) {
 	// Compiled regular expressions live on the heap. Compiling them lazily
 	// saves memory if this function is never called.
 	initRegexpsOnce.Do(initRegexps)
-	p := blockParser{lines: lineSplitter{text, 0}, codec: codec}
+	p := blockParser{lines: lineSplitter{text, 0, 0}, codec: codec}
 	p.render()
 }
 
@@ -316,7 +319,7 @@ const (
 	scheme           = `[a-zA-Z][a-zA-Z0-9+.-]{1,31}`
 	emailLocalPuncts = ".!#$%&'*+/=?^_`{|}~-"
 
-	// https://spec.commonmark.org/0.30/#open-tag
+	// https://spec.commonmark.org/0.31.2/#open-tag
 	openTag = `<` +
 		`[a-zA-Z][a-zA-Z0-9-]*` + // tag name
 		(`(?:` +
@@ -326,7 +329,7 @@ const (
 			`)*`) + // zero or more attributes
 		`[ \t\n]*` + // whitespace
 		`/?>`
-	// https://spec.commonmark.org/0.30/#closing-tag
+	// https://spec.commonmark.org/0.31.2/#closing-tag
 	closingTag = `</[a-zA-Z][a-zA-Z0-9-]*[ \t\n]*>`
 )
 
@@ -355,6 +358,8 @@ func initRegexps() {
 	// Capture group 1: fence punctuations
 	codeFenceCloserRegexp = regexp.MustCompile("(?:^ {0,3})(`{3,}|~{3,})[ \t]*$")
 
+	// These corresponds to the bullet list in
+	// https://spec.commonmark.org/0.31.2/#html-blocks.
 	html1Regexp = regexp.MustCompile(`^ {0,3}<(?i:pre|script|style|textarea)`)
 	html1CloserRegexp = regexp.MustCompile(`</(?i:pre|script|style|textarea)`)
 	html2Regexp = regexp.MustCompile(`^ {0,3}<!--`)
@@ -366,14 +371,14 @@ func initRegexps() {
 	html5Regexp = regexp.MustCompile(`^ {0,3}<!\[CDATA\[`)
 	html5CloserRegexp = regexp.MustCompile(`\]\]>`)
 
-	html6Regexp = regexp.MustCompile(`^ {0,3}</?(?i:address|article|aside|base|basefont|blockquote|body|caption|center|col|colgroup|dd|details|dialog|dir|div|dl|dt|fieldset|figcaption|figure|footer|form|frame|frameset|h1|h2|h3|h4|h5|h6|head|header|hr|html|iframe|legend|li|link|main|menu|menuitem|nav|noframes|ol|optgroup|option|p|param|section|summary|table|tbody|td|tfoot|th|thead|title|tr|track|ul)(?:[ \t>]|$|/>)`)
+	html6Regexp = regexp.MustCompile(`^ {0,3}</?(?i:address|article|aside|base|basefont|blockquote|body|caption|center|col|colgroup|dd|details|dialog|dir|div|dl|dt|fieldset|figcaption|figure|footer|form|frame|frameset|h1|h2|h3|h4|h5|h6|head|header|hr|html|iframe|legend|li|link|main|menu|menuitem|nav|noframes|ol|optgroup|option|p|param|search|section|summary|table|tbody|td|tfoot|th|thead|title|tr|track|ul)(?:[ \t>]|$|/>)`)
 	html7Regexp = regexp.MustCompile(
 		fmt.Sprintf(`^ {0,3}(?:%s|%s)[ \t]*$`, openTag, closingTag))
 
-	// https://spec.commonmark.org/0.30/#uri-autolink
+	// https://spec.commonmark.org/0.31.2/#uri-autolink
 	uriAutolinkRegexp = regexp.MustCompile(
 		`^<` + scheme + `:[^\x00-\x19 <>]*` + `>`)
-	// https://spec.commonmark.org/0.30/#email-autolink
+	// https://spec.commonmark.org/0.31.2/#email-autolink
 	emailAutolinkRegexp = regexp.MustCompile(
 		`^<[a-zA-Z0-9` + emailLocalPuncts + `]+@[a-zA-Z0-9](?:[a-zA-Z0-9-]{0,61}[a-zA-Z0-9])?(?:\.[a-zA-Z0-9](?:[a-zA-Z0-9-]{0,61}[a-zA-Z0-9])?)*>`)
 
@@ -385,32 +390,32 @@ const indentedCodePrefix = "    "
 
 func (p *blockParser) render() {
 	for p.lines.more() {
-		line := p.lines.next()
-		line, matchedContainers, newItem := p.tree.processContainerMarkers(line, p.codec)
+		line, lineNo := p.lines.next()
+		line, matchedContainers, newItem := p.tree.processContainerMarkers(line, lineNo, p.codec)
 
 		if isBlankLine(line) {
 			// Blank lines terminate blockquote if the continuation marker is
 			// absent.
 			if i, unmatched := p.tree.unmatchedBlockquote(matchedContainers); unmatched {
-				p.tree.closeBlocks(i, p.codec)
+				p.tree.closeBlocks(i, lineNo, p.codec)
 				continue
 			}
 			if newItem && p.lines.more() {
 				// A list item can start with at most one blank line; the second
 				// blank closes it.
-				nextLine := p.lines.next()
+				nextLine, _ := p.lines.next()
 				nextLine, _ = p.tree.matchContinuationMarkers(nextLine)
 				p.lines.backup()
 				if isBlankLine(nextLine) {
-					p.tree.closeBlocks(len(p.tree.containers)-1, p.codec)
+					p.tree.closeBlocks(len(p.tree.containers)-1, lineNo, p.codec)
 				}
 			}
-			p.tree.closeParagraph(p.codec)
+			p.tree.closeParagraph(lineNo, p.codec)
 		} else if thematicBreakRegexp.MatchString(line) {
-			p.tree.closeBlocks(matchedContainers, p.codec)
-			p.codec.Do(Op{Type: OpThematicBreak})
+			p.tree.closeBlocks(matchedContainers, lineNo, p.codec)
+			p.codec.Do(Op{Type: OpThematicBreak, LineNo: lineNo})
 		} else if m := atxHeadingRegexp.FindStringSubmatchIndex(line); m != nil {
-			p.tree.closeBlocks(matchedContainers, p.codec)
+			p.tree.closeBlocks(matchedContainers, lineNo, p.codec)
 			openerStart, openerEnd := m[2], m[3]
 			opener := line[openerStart:openerEnd]
 			line = strings.TrimRight(line[openerEnd:], " \t")
@@ -424,46 +429,46 @@ func (p *blockParser) render() {
 			}
 			level := len(opener)
 			p.codec.Do(Op{
-				Type: OpHeading, Number: level, Info: attr,
+				Type: OpHeading, LineNo: lineNo, Number: level, Info: attr,
 				Content: renderInline(strings.Trim(line, " \t"))})
 		} else if m := codeFenceRegexp.FindStringSubmatch(line); m != nil {
-			p.tree.closeBlocks(matchedContainers, p.codec)
+			p.tree.closeBlocks(matchedContainers, lineNo, p.codec)
 			indent, opener, info := len(m[1]), m[2], m[3]
 			if opener == "" {
 				opener, info = m[4], m[5]
 			}
 			p.parseFencedCodeBlock(indent, opener, info)
 		} else if len(p.tree.paragraph) == 0 && strings.HasPrefix(line, indentedCodePrefix) {
-			p.tree.closeBlocks(matchedContainers, p.codec)
+			p.tree.closeBlocks(matchedContainers, lineNo, p.codec)
 			p.parseIndentedCodeBlock(line)
 		} else if html1Regexp.MatchString(line) {
-			p.tree.closeBlocks(matchedContainers, p.codec)
+			p.tree.closeBlocks(matchedContainers, lineNo, p.codec)
 			p.parseCloserTerminatedHTMLBlock(line, html1CloserRegexp.MatchString)
 		} else if html2Regexp.MatchString(line) {
-			p.tree.closeBlocks(matchedContainers, p.codec)
+			p.tree.closeBlocks(matchedContainers, lineNo, p.codec)
 			p.parseCloserTerminatedHTMLBlock(line, html2CloserRegexp.MatchString)
 		} else if html3Regexp.MatchString(line) {
-			p.tree.closeBlocks(matchedContainers, p.codec)
+			p.tree.closeBlocks(matchedContainers, lineNo, p.codec)
 			p.parseCloserTerminatedHTMLBlock(line, html3CloserRegexp.MatchString)
 		} else if html4Regexp.MatchString(line) {
-			p.tree.closeBlocks(matchedContainers, p.codec)
+			p.tree.closeBlocks(matchedContainers, lineNo, p.codec)
 			p.parseCloserTerminatedHTMLBlock(line, html4CloserRegexp.MatchString)
 		} else if html5Regexp.MatchString(line) {
-			p.tree.closeBlocks(matchedContainers, p.codec)
+			p.tree.closeBlocks(matchedContainers, lineNo, p.codec)
 			p.parseCloserTerminatedHTMLBlock(line, html5CloserRegexp.MatchString)
 		} else if html6Regexp.MatchString(line) || (len(p.tree.paragraph) == 0 && html7Regexp.MatchString(line)) {
-			p.tree.closeBlocks(matchedContainers, p.codec)
+			p.tree.closeBlocks(matchedContainers, lineNo, p.codec)
 			p.parseBlankLineTerminatedHTMLBlock(line)
 		} else {
 			if len(p.tree.paragraph) == 0 {
 				// This is not lazy continuation, so close all unmatched
 				// containers.
-				p.tree.closeBlocks(matchedContainers, p.codec)
+				p.tree.closeBlocks(matchedContainers, lineNo, p.codec)
 			}
 			p.tree.paragraph = append(p.tree.paragraph, line)
 		}
 	}
-	p.tree.closeBlocks(0, p.codec)
+	p.tree.closeBlocks(0, p.lines.lastLineNo+1, p.codec)
 }
 
 func isBlankLine(line string) bool {
@@ -475,17 +480,18 @@ func (p *blockParser) parseFencedCodeBlock(indent int, opener, info string) {
 	// the info string before trimming.
 	info = strings.Trim(processCodeFenceInfo(info), " \t")
 	var lines []string
+	startLineNo := p.lines.lastLineNo
 	doCodeBlock := func() {
-		p.codec.Do(Op{Type: OpCodeBlock, Info: info, Lines: lines})
+		p.codec.Do(Op{Type: OpCodeBlock, LineNo: startLineNo, Info: info, Lines: lines})
 	}
 
 	for p.lines.more() {
-		line := p.lines.next()
+		line, lineNo := p.lines.next()
 		line, matchedContainers := p.tree.matchContinuationMarkers(line)
 		if isBlankLine(line) {
 			if i, unmatched := p.tree.unmatchedBlockquote(matchedContainers); unmatched {
 				doCodeBlock()
-				p.tree.closeBlocks(i, p.codec)
+				p.tree.closeBlocks(i, lineNo, p.codec)
 				return
 			}
 		} else if matchedContainers < len(p.tree.containers) {
@@ -533,16 +539,17 @@ func processCodeFenceInfo(text string) string {
 
 func (p *blockParser) parseIndentedCodeBlock(line string) {
 	lines := []string{strings.TrimPrefix(line, indentedCodePrefix)}
-	doCodeBlock := func() { p.codec.Do(Op{Type: OpCodeBlock, Lines: lines}) }
+	startLineNo := p.lines.lastLineNo
+	doCodeBlock := func() { p.codec.Do(Op{Type: OpCodeBlock, LineNo: startLineNo, Lines: lines}) }
 	var savedBlankLines []string
 
 	for p.lines.more() {
-		line := p.lines.next()
+		line, lineNo := p.lines.next()
 		line, matchedContainers := p.tree.matchContinuationMarkers(line)
 		if isBlankLine(line) {
 			if i, unmatched := p.tree.unmatchedBlockquote(matchedContainers); unmatched {
 				doCodeBlock()
-				p.tree.closeBlocks(i, p.codec)
+				p.tree.closeBlocks(i, lineNo, p.codec)
 				return
 			}
 			if strings.HasPrefix(line, indentedCodePrefix) {
@@ -565,8 +572,9 @@ func (p *blockParser) parseIndentedCodeBlock(line string) {
 
 func (p *blockParser) parseCloserTerminatedHTMLBlock(line string, closer func(string) bool) {
 	lines := []string{line}
+	startLineNo := p.lines.lastLineNo
 	doHTMLBlock := func() {
-		p.codec.Do(Op{Type: OpHTMLBlock, Lines: lines})
+		p.codec.Do(Op{Type: OpHTMLBlock, LineNo: startLineNo, Lines: lines})
 	}
 
 	if closer(line) {
@@ -575,12 +583,12 @@ func (p *blockParser) parseCloserTerminatedHTMLBlock(line string, closer func(st
 	}
 	var savedBlankLines []string
 	for p.lines.more() {
-		line := p.lines.next()
+		line, lineNo := p.lines.next()
 		line, matchedContainers := p.tree.matchContinuationMarkers(line)
 		if isBlankLine(line) {
 			if i, unmatched := p.tree.unmatchedBlockquote(matchedContainers); unmatched {
 				doHTMLBlock()
-				p.tree.closeBlocks(i, p.codec)
+				p.tree.closeBlocks(i, lineNo, p.codec)
 				return
 			}
 			savedBlankLines = append(savedBlankLines, line)
@@ -603,15 +611,16 @@ func (p *blockParser) parseCloserTerminatedHTMLBlock(line string, closer func(st
 
 func (p *blockParser) parseBlankLineTerminatedHTMLBlock(line string) {
 	lines := []string{line}
-	doHTMLBlock := func() { p.codec.Do(Op{Type: OpHTMLBlock, Lines: lines}) }
+	startLineNo := p.lines.lastLineNo
+	doHTMLBlock := func() { p.codec.Do(Op{Type: OpHTMLBlock, LineNo: startLineNo, Lines: lines}) }
 
 	for p.lines.more() {
-		line := p.lines.next()
+		line, lineNo := p.lines.next()
 		line, matchedContainers := p.tree.matchContinuationMarkers(line)
 		if isBlankLine(line) {
 			doHTMLBlock()
 			if i, unmatched := p.tree.unmatchedBlockquote(matchedContainers); unmatched {
-				p.tree.closeBlocks(i, p.codec)
+				p.tree.closeBlocks(i, lineNo, p.codec)
 			}
 			return
 		} else if matchedContainers < len(p.tree.containers) {
@@ -624,7 +633,7 @@ func (p *blockParser) parseBlankLineTerminatedHTMLBlock(line string) {
 }
 
 // This struct corresponds to the block tree in
-// https://spec.commonmark.org/0.30/#phase-1-block-structure.
+// https://spec.commonmark.org/0.31.2/#phase-1-block-structure.
 //
 // The spec describes a two-phased parsing strategy where the entire block tree
 // is built before inline parsing is done. However, since we don't support
@@ -666,7 +675,7 @@ type blockTree struct {
 // The latter should be used to call t.closeContainers
 // unless the remaining content of the line constitutes a blank line or
 // paragraph continuation.
-func (t *blockTree) processContainerMarkers(line string, codec Codec) (string, int, bool) {
+func (t *blockTree) processContainerMarkers(line string, lineNo int, codec Codec) (string, int, bool) {
 	line, matched := t.matchContinuationMarkers(line)
 	line, newContainers := t.parseStartingMarkers(line,
 		// This argument tells parseStartingMarkers whether we are starting a
@@ -697,7 +706,7 @@ func (t *blockTree) processContainerMarkers(line string, codec Codec) (string, i
 		return line, matched, false
 	}
 
-	t.closeBlocks(matched, codec)
+	t.closeBlocks(matched, lineNo, codec)
 	for _, c := range newContainers {
 		if c.typ.isItem() {
 			if continueList {
@@ -705,11 +714,11 @@ func (t *blockTree) processContainerMarkers(line string, codec Codec) (string, i
 			} else {
 				list := container{typ: c.typ.itemToList(), punct: c.punct, start: c.start}
 				t.containers = append(t.containers, list)
-				codec.Do(Op{Type: containerOpenOp[list.typ], Number: list.start})
+				codec.Do(Op{Type: containerOpenOp[list.typ], LineNo: lineNo, Number: list.start})
 			}
 		}
 		t.containers = append(t.containers, c)
-		codec.Do(Op{Type: containerOpenOp[c.typ]})
+		codec.Do(Op{Type: containerOpenOp[c.typ], LineNo: lineNo})
 	}
 	return line, len(t.containers), newContainers[len(newContainers)-1].typ.isItem()
 }
@@ -745,10 +754,10 @@ func (t *blockTree) unmatchedBlockquote(matched int) (int, bool) {
 }
 
 var (
-	// https://spec.commonmark.org/0.30/#block-quotes
+	// https://spec.commonmark.org/0.31.2/#block-quotes
 	blockquoteMarkerRegexp = regexp.MustCompile(`^ {0,3}> ?`)
 
-	// Rule #1 and #2 of https://spec.commonmark.org/0.30/#list-items
+	// Rule #1 and #2 of https://spec.commonmark.org/0.31.2/#list-items
 	itemStartingMarkerRegexp = regexp.MustCompile(
 		// Capture groups:
 		// 1. bullet item punctuation
@@ -757,7 +766,7 @@ var (
 		// 4. trailing spaces
 		`^ {0,3}(?:([-+*])|([0-9]{1,9})([.)]))( +)`)
 
-	// Rule #3 of https://spec.commonmark.org/0.30/#list-items
+	// Rule #3 of https://spec.commonmark.org/0.31.2/#list-items
 	itemStartingMarkerBlankLineRegexp = regexp.MustCompile(
 		// Capture groups are the same, with group 4 always empty.
 		`^ {0,3}(?:([-+*])|([0-9]{1,9})([.)]))[ \t]*()$`)
@@ -767,7 +776,7 @@ var (
 // all starting markers and new containers to create.
 //
 // Blockquotes are simple to parse. Most of the code deals with list items,
-// described in https://spec.commonmark.org/0.30/#list-items.
+// described in https://spec.commonmark.org/0.31.2/#list-items.
 func (t *blockTree) parseStartingMarkers(line string, newParagraph bool) (string, []container) {
 	var containers []container
 	// Exception 2 of rule #1: Don't parse thematic breaks like "- - - " as
@@ -822,21 +831,23 @@ func (t *blockTree) parseStartingMarkers(line string, newParagraph bool) (string
 	return line, containers
 }
 
-func (t *blockTree) closeBlocks(keep int, codec Codec) {
-	t.closeParagraph(codec)
+func (t *blockTree) closeBlocks(keep, lineNo int, codec Codec) {
+	t.closeParagraph(lineNo, codec)
 	for i := len(t.containers) - 1; i >= keep; i-- {
-		codec.Do(Op{Type: containerCloseOp[t.containers[i].typ]})
+		codec.Do(Op{Type: containerCloseOp[t.containers[i].typ], LineNo: lineNo})
 	}
 	t.containers = t.containers[:keep]
 }
 
-func (t *blockTree) closeParagraph(codec Codec) {
+// lineNo identifies the first line not part of the paragraph.
+func (t *blockTree) closeParagraph(lineNo int, codec Codec) {
 	if len(t.paragraph) == 0 {
 		return
 	}
+	startLineNo := lineNo - len(t.paragraph)
 	text := strings.Trim(strings.Join(t.paragraph, "\n"), " \t")
 	t.paragraph = t.paragraph[:0]
-	codec.Do(Op{Type: OpParagraph, Content: renderInline(text)})
+	codec.Do(Op{Type: OpParagraph, LineNo: startLineNo, Content: renderInline(text)})
 }
 
 type container struct {
@@ -905,21 +916,25 @@ func (c container) matchContinuationMarker(line string) (int, bool) {
 type lineSplitter struct {
 	text string
 	pos  int
+	// Line number of the last line returned by next.
+	lastLineNo int
 }
 
 func (s *lineSplitter) more() bool {
 	return s.pos < len(s.text)
 }
 
-func (s *lineSplitter) next() string {
+func (s *lineSplitter) next() (string, int) {
 	begin := s.pos
 	delta := strings.IndexByte(s.text[begin:], '\n')
 	if delta == -1 {
 		s.pos = len(s.text)
-		return s.text[begin:]
+		s.lastLineNo++
+		return s.text[begin:], s.lastLineNo
 	}
 	s.pos += delta + 1
-	return s.text[begin : s.pos-1]
+	s.lastLineNo++
+	return s.text[begin : s.pos-1], s.lastLineNo
 }
 
 func (s *lineSplitter) backup() {
@@ -927,6 +942,7 @@ func (s *lineSplitter) backup() {
 		return
 	}
 	s.pos = 1 + strings.LastIndexByte(s.text[:s.pos-1], '\n')
+	s.lastLineNo--
 }
 
 var leftAnchoredCharRefRegexp = regexp.MustCompile(`^` + charRefPattern)
