@@ -2,7 +2,6 @@
 package runtime
 
 import (
-	_ "embed"
 	"os"
 
 	"src.elv.sh/pkg/eval"
@@ -31,11 +30,6 @@ func Ns(ev *eval.Evaler) *eval.Ns {
 		}).Ns()
 }
 
-// DElvCode contains the content of the .d.elv file for this module.
-//
-//go:embed *.d.elv
-var DElvCode string
-
 func nonEmptyOrNil(s string) any {
 	if s == "" {
 		return nil
