@@ -5,7 +5,6 @@ import (
 	"errors"
 	"fmt"
 	"io"
-	"reflect"
 	"strings"
 	"unicode/utf8"
 
@@ -14,7 +13,7 @@ import (
 
 // parser maintains some mutable states of parsing.
 //
-// NOTE: The str member is assumed to be valid UF-8.
+// NOTE: The src member is assumed to be valid UF-8.
 type parser struct {
 	srcName string
 	src     string
@@ -32,45 +31,34 @@ type ErrorTag struct{}
 
 func (ErrorTag) ErrorTag() string { return "parse error" }
 
-func (ps *parser) parse(n Node) parsed {
+func parse[N Node](ps *parser, n N) parsed[N] {
 	begin := ps.pos
 	n.n().From = begin
 	n.parse(ps)
 	n.n().To = ps.pos
 	n.n().sourceText = ps.src[begin:ps.pos]
-	return parsed{n}
+	return parsed[N]{n}
 }
 
-type parserState struct {
-	pos     int
-	overEOF int
-	errors  []*Error
+type parsed[N Node] struct {
+	n N
 }
 
-func (ps *parser) save() parserState {
-	return parserState{ps.pos, ps.overEOF, ps.errors}
-}
-
-func (ps *parser) restore(s parserState) {
-	ps.pos, ps.overEOF, ps.errors = s.pos, s.overEOF, s.errors
-}
-
-type parsed struct {
-	n Node
-}
-
-func (p parsed) addAs(ptr any, parent Node) {
-	dst := reflect.ValueOf(ptr).Elem()
-	dst.Set(reflect.ValueOf(p.n)) // *ptr = p.n
+func (p parsed[N]) addAs(ptr *N, parent Node) {
+	*ptr = p.n
 	addChild(parent, p.n)
 }
 
-func (p parsed) addTo(ptr any, parent Node) {
-	dst := reflect.ValueOf(ptr).Elem()
-	dst.Set(reflect.Append(dst, reflect.ValueOf(p.n))) // *ptr = append(*ptr, n)
+func (p parsed[N]) addTo(ptr *[]N, parent Node) {
+	*ptr = append(*ptr, p.n)
 	addChild(parent, p.n)
 }
 
+func addChild(p Node, ch Node) {
+	p.n().addChild(ch)
+	ch.n().parent = p
+}
+
 // Tells the parser that parsing is done.
 func (ps *parser) done() {
 	if ps.pos != len(ps.src) {
@@ -115,7 +103,9 @@ func (ps *parser) backup() {
 func (ps *parser) errorp(r diag.Ranger, e error) {
 	err := &Error{
 		Message: e.Error(),
-		Context: *diag.NewContext(ps.srcName, ps.src, r)}
+		Context: *diag.NewContext(ps.srcName, ps.src, r),
+		Partial: r.Range().From == len(ps.src),
+	}
 	ps.errors = append(ps.errors, err)
 }
 
