@@ -29,7 +29,10 @@ func (p *Program) Run(fds [3]*os.File, _ []string) error {
 			fmt.Fprintln(fds[2], "Continuing without CPU profiling.")
 		} else {
 			pprof.StartCPUProfile(f)
-			cleanups = append(cleanups, func([3]*os.File) { pprof.StopCPUProfile() })
+			cleanups = append(cleanups, func([3]*os.File) {
+				pprof.StopCPUProfile()
+				f.Close()
+			})
 		}
 	}
 	if p.allocsProfile != "" {
@@ -46,9 +49,3 @@ func (p *Program) Run(fds [3]*os.File, _ []string) error {
 	}
 	return prog.NextProgram(cleanups...)
 }
-
-func (p *Program) Cleanup() {
-	if p.cpuProfile != "" {
-		pprof.StopCPUProfile()
-	}
-}
