@@ -9,10 +9,10 @@ import (
 var Args = tt.Args
 
 func TestCamelToDashed(t *testing.T) {
-	tt.Test(t, tt.Fn("CamelToDashed", CamelToDashed), tt.Table{
+	tt.Test(t, CamelToDashed,
 		Args("CamelCase").Rets("camel-case"),
 		Args("camelCase").Rets("-camel-case"),
 		Args("HTTP").Rets("http"),
 		Args("HTTPRequest").Rets("http-request"),
-	})
+	)
 }
