@@ -7,10 +7,10 @@ import (
 )
 
 func TestTitle(t *testing.T) {
-	tt.Test(t, tt.Fn("Title", Title), tt.Table{
+	tt.Test(t, Title,
 		Args("").Rets(""),
 		Args("foo").Rets("Foo"),
 		Args("\xf0").Rets("\xf0"),
 		Args("FOO").Rets("FOO"),
-	})
+	)
 }
