@@ -58,11 +58,16 @@ func (term *Termios) SetEcho(v bool) {
 	setFlag(&term.Lflag, unix.ECHO, v)
 }
 
-// SetICRNL sets the CRNL iflag bit
+// SetICRNL sets the CRNL iflag bit.
 func (term *Termios) SetICRNL(v bool) {
 	setFlag(&term.Iflag, unix.ICRNL, v)
 }
 
+// SetIXON sets the IXON iflag bit.
+func (term *Termios) SetIXON(v bool) {
+	setFlag(&term.Iflag, unix.IXON, v)
+}
+
 func setFlag(flag *termiosFlag, mask termiosFlag, v bool) {
 	if v {
 		*flag |= mask
